import _minBy from "lodash/minBy";import _maxBy from "lodash/maxBy";(function () {var enterModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.enterModule : undefined;enterModule && enterModule(module);})();var __signature__ = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default.signature : function (a) {return a;}; /**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import {
  GenericDataType,
  NumberFormats,

  getColumnLabel,
  getMetricLabel,
  getSequentialSchemeRegistry,
  getTimeFormatter,
  getValueFormatter,
  tooltipHtml } from
'@superset-ui/core';
import memoizeOne from 'memoize-one';





import { getDefaultTooltip } from '../utils/tooltip';

import { parseAxisBound } from '../utils/controls';
import { NULL_STRING } from '../constants';
import { getPercentFormatter } from '../utils/formatters';



const DEFAULT_ECHARTS_BOUNDS = [0, 200];

// Calculated totals per x and y categories plus total
const calculateTotals = memoizeOne(
  (
  data,
  xAxis,
  groupby,
  metric) =>

  data.reduce(
    (acc, row) => {
      const value = row[metric];
      if (typeof value !== 'number') {
        return acc;
      }
      const x = row[xAxis];
      const y = row[groupby];
      const xTotal = acc.x[x] || 0;
      const yTotal = acc.y[y] || 0;
      return {
        x: { ...acc.x, [x]: xTotal + value },
        y: { ...acc.y, [y]: yTotal + value },
        total: acc.total + value
      };
    },
    { x: {}, y: {}, total: 0 }
  )
);

export default function transformProps(
chartProps)
{var _getSequentialSchemeR;
  const refs = {};
  const { width, height, formData, queriesData, datasource } = chartProps;
  const {
    bottomMargin,
    xAxis,
    groupby,
    linearColorScheme,
    leftMargin,
    legendType = 'continuous',
    metric = '',
    normalizeAcross,
    normalized,
    showLegend,
    showPercentage,
    showValues,
    xscaleInterval,
    yscaleInterval,
    valueBounds,
    yAxisFormat,
    xAxisTimeFormat,
    currencyFormat
  } = formData;
  const metricLabel = getMetricLabel(metric);
  const xAxisLabel = getColumnLabel(xAxis);
  // groupby is overridden to be a single value
  const yAxisLabel = getColumnLabel(groupby);
  const { data, colnames, coltypes } = queriesData[0];
  const { columnFormats = {}, currencyFormats = {} } = datasource;
  const colorColumn = normalized ? 'rank' : metricLabel;
  const colors = (_getSequentialSchemeR = getSequentialSchemeRegistry().get(linearColorScheme)) == null ? void 0 : _getSequentialSchemeR.colors;
  const getAxisFormatter =
  (colType) => (value) => {
    if (colType === GenericDataType.Temporal) {
      if (typeof value === 'string') {
        return getTimeFormatter(xAxisTimeFormat)(Number.parseInt(value, 10));
      }
      return getTimeFormatter(xAxisTimeFormat)(value);
    }
    return String(value);
  };

  const xAxisFormatter = getAxisFormatter(coltypes[0]);
  const yAxisFormatter = getAxisFormatter(coltypes[1]);
  const percentFormatter = getPercentFormatter(NumberFormats.PERCENT_2_POINT);
  const valueFormatter = getValueFormatter(
    metric,
    currencyFormats,
    columnFormats,
    yAxisFormat,
    currencyFormat
  );

  let [min, max] = (valueBounds || []).map(parseAxisBound);
  if (min === undefined) {var _minBy2;
    min =
    ((_minBy2 = _minBy(data, (row) => row[colorColumn])) == null ? void 0 : _minBy2[colorColumn]) ||
    DEFAULT_ECHARTS_BOUNDS[0];
  }
  if (max === undefined) {var _maxBy2;
    max =
    ((_maxBy2 = _maxBy(data, (row) => row[colorColumn])) == null ? void 0 : _maxBy2[colorColumn]) ||
    DEFAULT_ECHARTS_BOUNDS[1];
  }

  const series = [
  {
    name: metricLabel,
    type: 'heatmap',
    data: data.map((row) =>
    colnames.map((col) => {
      const value = row[col];
      if (!value) {
        return NULL_STRING;
      }
      if (typeof value === 'boolean') {
        return String(value);
      }
      return value;
    })
    ),
    label: {
      show: showValues,
      formatter: (params) => {var _params$value;return (
          valueFormatter((_params$value = params.value) == null ? void 0 : _params$value[2]));}
    }
  }];


  const echartOptions = {
    grid: {
      containLabel: true,
      bottom: bottomMargin,
      left: leftMargin
    },
    series,
    tooltip: {
      ...getDefaultTooltip(refs),
      formatter: (params) => {var _params$value2, _params$value3, _params$value4;
        const totals = calculateTotals(
          data,
          xAxisLabel,
          yAxisLabel,
          metricLabel
        );
        const x = (_params$value2 = params.value) == null ? void 0 : _params$value2[0];
        const y = (_params$value3 = params.value) == null ? void 0 : _params$value3[1];
        const value = (_params$value4 = params.value) == null ? void 0 : _params$value4[2];
        const formattedX = xAxisFormatter(x);
        const formattedY = yAxisFormatter(y);
        const formattedValue = valueFormatter(value);
        let percentage = 0;
        let suffix = 'heatmap';
        if (typeof value === 'number') {
          if (normalizeAcross === 'x') {
            percentage = value / totals.x[x];
            suffix = formattedX;
          } else if (normalizeAcross === 'y') {
            percentage = value / totals.y[y];
            suffix = formattedY;
          } else {
            percentage = value / totals.total;
            suffix = 'heatmap';
          }
        }
        const title = `${formattedX} (${formattedY})`;
        const row = [colnames[2], formattedValue];
        if (showPercentage) {
          row.push(`${percentFormatter(percentage)} (${suffix})`);
        }
        return tooltipHtml([row], title);
      }
    },
    visualMap: {
      type: legendType,
      min,
      max,
      calculable: true,
      orient: 'horizontal',
      right: 0,
      top: 0,
      itemHeight: legendType === 'continuous' ? 300 : 14,
      itemWidth: 15,
      formatter: (min) => valueFormatter(min),
      inRange: {
        color: colors
      },
      show: showLegend,
      // By default, ECharts uses the last dimension which is rank
      dimension: normalized ? 3 : 2
    },
    xAxis: {
      type: 'category',
      axisLabel: {
        formatter: xAxisFormatter,
        interval: xscaleInterval === -1 ? 'auto' : xscaleInterval - 1
      }
    },
    yAxis: {
      type: 'category',
      axisLabel: {
        formatter: yAxisFormatter,
        interval: yscaleInterval === -1 ? 'auto' : yscaleInterval - 1
      }
    }
  };
  return {
    refs,
    echartOptions,
    width,
    height,
    formData
  };
};(function () {var reactHotLoader = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default : undefined;if (!reactHotLoader) {return;}reactHotLoader.register(DEFAULT_ECHARTS_BOUNDS, "DEFAULT_ECHARTS_BOUNDS", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Heatmap/transformProps.ts");reactHotLoader.register(calculateTotals, "calculateTotals", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Heatmap/transformProps.ts");reactHotLoader.register(transformProps, "transformProps", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Heatmap/transformProps.ts");})();;(function () {var leaveModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.leaveModule : undefined;leaveModule && leaveModule(module);})();
//# sourceMappingURL=transformProps.js.map