(function () {var enterModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.enterModule : undefined;enterModule && enterModule(module);})();var __signature__ = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default.signature : function (a) {return a;}; /**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t } from '@superset-ui/core';
import {


  ControlSubSectionHeader,
  D3_FORMAT_DOCS,
  D3_NUMBER_FORMAT_DESCRIPTION_VALUES_TEXT,
  D3_FORMAT_OPTIONS,
  D3_TIME_FORMAT_OPTIONS,
  getStandardizedControls } from
'@superset-ui/chart-controls';
import { DEFAULT_FORM_DATA } from './types';import { jsx as _jsx } from "@emotion/react/jsx-runtime";

const { labelType, numberFormat, showLabels } = DEFAULT_FORM_DATA;

const config = {
  controlPanelSections: [
  {
    label: t('Query'),
    expanded: true,
    controlSetRows: [
    ['columns'],
    ['metric'],
    ['secondary_metric'],
    ['adhoc_filters'],
    ['row_limit'],
    ['sort_by_metric']]

  },
  {
    label: t('Chart Options'),
    expanded: true,
    controlSetRows: [
    ['color_scheme'],
    ['linear_color_scheme'],
    [_jsx(ControlSubSectionHeader, { children: t('Labels') })],
    [
    {
      name: 'show_labels',
      config: {
        type: 'CheckboxControl',
        label: t('Show Labels'),
        renderTrigger: true,
        default: showLabels,
        description: t('Whether to display the labels.')
      }
    }],

    [
    {
      name: 'show_labels_threshold',
      config: {
        type: 'TextControl',
        label: t('Percentage threshold'),
        renderTrigger: true,
        isFloat: true,
        default: 5,
        description: t(
          'Minimum threshold in percentage points for showing labels.'
        )
      }
    }],

    [
    {
      name: 'show_total',
      config: {
        type: 'CheckboxControl',
        label: t('Show Total'),
        default: false,
        renderTrigger: true,
        description: t('Whether to display the aggregate count')
      }
    }],

    [
    {
      name: 'label_type',
      config: {
        type: 'SelectControl',
        label: t('Label Type'),
        default: labelType,
        renderTrigger: true,
        choices: [
        ['key', t('Category Name')],
        ['value', t('Value')],
        ['key_value', t('Category and Value')]],

        description: t('What should be shown on the label?')
      }
    }],

    [
    {
      name: 'number_format',
      config: {
        type: 'SelectControl',
        freeForm: true,
        label: t('Number format'),
        renderTrigger: true,
        default: numberFormat,
        choices: D3_FORMAT_OPTIONS,
        description: `${D3_FORMAT_DOCS} ${D3_NUMBER_FORMAT_DESCRIPTION_VALUES_TEXT}`
      }
    }],

    ['currency_format'],
    [
    {
      name: 'date_format',
      config: {
        type: 'SelectControl',
        freeForm: true,
        label: t('Date format'),
        renderTrigger: true,
        choices: D3_TIME_FORMAT_OPTIONS,
        default: 'smart_date',
        description: D3_FORMAT_DOCS
      }
    }]]


  }],

  controlOverrides: {
    metric: {
      label: t('Primary Metric'),
      description: t(
        'The primary metric is used to define the arc segment sizes'
      )
    },
    secondary_metric: {
      label: t('Secondary Metric'),
      default: null,
      description: t(
        '[optional] this secondary metric is used to ' +
        'define the color as a ratio against the primary metric. ' +
        'When omitted, the color is categorical and based on labels'
      )
    },
    color_scheme: {
      description: t(
        'When only a primary metric is provided, a categorical color scale is used.'
      ),
      visibility: ({ controls }) => {var _controls$secondary_m, _controls$secondary_m2;return (
          Boolean(
            !(controls != null && (_controls$secondary_m = controls.secondary_metric) != null && _controls$secondary_m.value) ||
            (controls == null ? void 0 : (_controls$secondary_m2 = controls.secondary_metric) == null ? void 0 : _controls$secondary_m2.value) === (controls == null ? void 0 : controls.metric.value)
          ));}
    },
    linear_color_scheme: {
      description: t(
        'When a secondary metric is provided, a linear color scale is used.'
      ),
      visibility: ({ controls }) => {var _controls$secondary_m3, _controls$secondary_m4;return (
          Boolean(
            (controls == null ? void 0 : (_controls$secondary_m3 = controls.secondary_metric) == null ? void 0 : _controls$secondary_m3.value) &&
            (controls == null ? void 0 : (_controls$secondary_m4 = controls.secondary_metric) == null ? void 0 : _controls$secondary_m4.value) !== (controls == null ? void 0 : controls.metric.value)
          ));}
    },
    columns: {
      label: t('Hierarchy'),
      description: t(`Sets the hierarchy levels of the chart. Each level is
        represented by one ring with the innermost circle as the top of the hierarchy.`)
    }
  },
  formDataOverrides: (formData) => ({
    ...formData,
    groupby: getStandardizedControls().popAllColumns(),
    metric: getStandardizedControls().shiftMetric(),
    secondary_metric: getStandardizedControls().shiftMetric()
  })
};const _default =

config;export default _default;;(function () {var reactHotLoader = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default : undefined;if (!reactHotLoader) {return;}reactHotLoader.register(labelType, "labelType", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Sunburst/controlPanel.tsx");reactHotLoader.register(numberFormat, "numberFormat", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Sunburst/controlPanel.tsx");reactHotLoader.register(showLabels, "showLabels", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Sunburst/controlPanel.tsx");reactHotLoader.register(config, "config", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Sunburst/controlPanel.tsx");reactHotLoader.register(_default, "default", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/plugin-chart-echarts/src/Sunburst/controlPanel.tsx");})();;(function () {var leaveModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.leaveModule : undefined;leaveModule && leaveModule(module);})();
//# sourceMappingURL=controlPanel.js.map